===========================
django-codenerix-transports
===========================

Codenerix Transports is a module that enables `CODENERIX <https://www.codenerix.com/>`_ to manage transports and let clients to request transport of packages with known companies.

.. image:: https://github.com/codenerix/django-codenerix/raw/master/codenerix/static/codenerix/img/codenerix.png
    :target: https://www.codenerix.com
    :alt: Try our demo with Codenerix Cloud

********
Features
********

* Comming soon: `MRW <http://www.mrw.es>`_

****
Demo
****

Comin soon...

**********
Quickstart
**********

1. Install this package::

    For python 2: sudo pip2 install django-codenerix-transports
    For python 3: sudo pip3 install django-codenerix-transports

2. Add "codenerix_transports" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'codenerix_transports',
    ]

3. Since Codenerix Transports is a library, you only need to import its parts into your project and use them.

*************
Documentation
*************

Coming soon... do you help us?

You can get in touch with us `here <https://codenerix.com/contact/>`_.

*******
Credits
*******

Several technologies have been used to build CODENERIX TRANSPORTS:

=================================== =================== =========================== =========================================================
Project name                        License             Owner                       Link to project
=================================== =================== =========================== =========================================================
Suds                                GNU Lesser GPL      Jurko Gospodnetic           http://bitbucket.org/jurko/suds
Django Countries                    MIT                 Chris Beaven                https://github.com/SmileyChris/django-countries/
=================================== =================== =========================== =========================================================

